@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -64,6 +64,10 @@ public:
   typedef std::vector<std::string>      path_list;
   typedef std::pair<uint64_t, Path>     split_type;
 
+  // The below are using-directives that make visible functions and
+  // typedefs in the parent std::vector, only those listed below are
+  // accessible. If you don't understand how this works, use google,
+  // don't ask me.
   using base_type::value_type;
   using base_type::iterator;
   using base_type::const_iterator;
@@ -77,6 +81,7 @@ public:
   using base_type::rbegin;
   using base_type::rend;
 
+  using base_type::front;
   using base_type::back;
   using base_type::empty;
   using base_type::reserve;
@@ -90,10 +95,12 @@ public:
   bool                is_open() const                                 { return m_isOpen; }
   bool                is_done() const                                 { return completed_chunks() == size_chunks(); }
   bool                is_valid_piece(const Piece& piece) const;
+  bool                is_root_dir_created() const;
 
   // Check if the torrent is loaded as a multi-file torrent. This may
   // return true even for a torrent with just one file.
   bool                is_multi_file() const;
+  void                set_multi_file(bool state)                      { m_isMultiFile = state; }
 
   size_t              size_files() const                              { return base_type::size(); }
   uint64_t            size_bytes() const                              { return m_torrentSize; }
@@ -111,6 +118,7 @@ public:
 
   // You may only call set_root_dir after all nodes have been added.
   const std::string&  root_dir() const                                { return m_rootDir; }
+  const std::string&  frozen_root_dir() const                         { return m_frozenRootDir; }
   void                set_root_dir(const std::string& path);
 
   uint64_t            max_file_size() const                           { return m_maxFileSize; }
@@ -120,6 +128,9 @@ public:
   // of free diskspace will be returned.
   uint64_t            free_diskspace() const;
 
+  // List of directories in the torrent that might be on different
+  // volumes as they are links, including the root directory. Used by
+  // 'free_diskspace()'.
   const path_list*    indirect_links() const                          { return &m_indirectLinks; }
 
   // The sum of the sizes in the range [first,last> must be equal to
@@ -133,14 +144,18 @@ public:
 
   void                update_paths(iterator first, iterator last);
 
+  bool                make_root_path();
+  bool                make_all_paths();
+
 protected:
+  static const int open_no_create        = (1 << 0);
+  static const int open_require_all_open = (1 << 1);
+
   void                initialize(uint64_t torrentSize, uint32_t chunkSize) LIBTORRENT_NO_EXPORT;
 
-  void                open() LIBTORRENT_NO_EXPORT;
+  void                open(int flags) LIBTORRENT_NO_EXPORT;
   void                close() LIBTORRENT_NO_EXPORT;
 
-  bool                resize_all() LIBTORRENT_NO_EXPORT;
-
   Bitfield*           mutable_bitfield()                               { return &m_bitfield; }
 
   // Before calling this function, make sure you clear errno. If
@@ -153,12 +168,10 @@ protected:
   void                update_completed() LIBTORRENT_NO_EXPORT;
 
 private:
-  bool                open_file(File* node, const Path& lastPath) LIBTORRENT_NO_EXPORT;
+  bool                open_file(File* node, const Path& lastPath, int flags) LIBTORRENT_NO_EXPORT;
   void                make_directory(Path::const_iterator pathBegin, Path::const_iterator pathEnd, Path::const_iterator startItr) LIBTORRENT_NO_EXPORT;
   MemoryChunk         create_chunk_part(FileList::iterator itr, uint64_t offset, uint32_t length, int prot) LIBTORRENT_NO_EXPORT;
 
-  void                set_match_depth(File* left, File* right);
-
   bool                m_isOpen;
 
   uint64_t            m_torrentSize;
@@ -169,6 +182,10 @@ private:
   Bitfield            m_bitfield;
 
   path_list           m_indirectLinks;
+
+  // Reorder next minor version bump:
+  bool                m_isMultiFile;
+  std::string         m_frozenRootDir;
 };
 
 }
